==> gdcm_2.0.14.orig.tar.gz: gdcm-2.0.14/Utilities/VTK/vtkImageYBRToRGB.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkImageYBRToRGB.h,v $

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkImageYBRToRGB - Converts YBR components to RGB.
// .SECTION Description
// For each pixel with hue, saturation and value components this filter
// outputs the color coded as red, green, blue.  Output type must be the same
// as input type.

// .SECTION See Also
// vtkImageRGBToHSV

#ifndef __vtkImageYBRToRGB_h
#define __vtkImageYBRToRGB_h

#include "vtkThreadedImageAlgorithm.h"
#include "gdcmTypes.h" // GDCM_EXPORT

class GDCM_EXPORT vtkImageYBRToRGB : public vtkThreadedImageAlgorithm
{
public:
  static vtkImageYBRToRGB *New();
  vtkTypeRevisionMacro(vtkImageYBRToRGB,vtkThreadedImageAlgorithm);

  void PrintSelf(ostream& os, vtkIndent indent);

protected:
  vtkImageYBRToRGB();
  ~vtkImageYBRToRGB() {};

  void ThreadedExecute (vtkImageData *inData, vtkImageData *outData,
                       int ext[6], int id);
private:
  vtkImageYBRToRGB(const vtkImageYBRToRGB&);  // Not implemented.
  void operator=(const vtkImageYBRToRGB&);  // Not implemented.
};

#endif

==> gdcm_2.0.15.orig.tar.gz: gdcm-2.0.15/Utilities/VTK/vtkImageYBRToRGB.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkImageYBRToRGB.h,v $

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkImageYBRToRGB - Converts YBR components to RGB.
// .SECTION Description
// For each pixel with hue, saturation and value components this filter
// outputs the color coded as red, green, blue.  Output type must be the same
// as input type.

// .SECTION See Also
// vtkImageRGBToHSV

#ifndef VTKIMAGEYBRTORGB_H
#define VTKIMAGEYBRTORGB_H

#include "vtkThreadedImageAlgorithm.h"

class VTK_EXPORT vtkImageYBRToRGB : public vtkThreadedImageAlgorithm
{
public:
  static vtkImageYBRToRGB *New();
  vtkTypeRevisionMacro(vtkImageYBRToRGB,vtkThreadedImageAlgorithm);

  void PrintSelf(ostream& os, vtkIndent indent);

protected:
  vtkImageYBRToRGB();
  ~vtkImageYBRToRGB() {};

  void ThreadedExecute (vtkImageData *inData, vtkImageData *outData,
                       int ext[6], int id);
private:
  vtkImageYBRToRGB(const vtkImageYBRToRGB&);  // Not implemented.
  void operator=(const vtkImageYBRToRGB&);  // Not implemented.
};

#endif
